@@ -1,35 +1,38 @@
 import os
 import os.path as op
 
-from datalad.api import Dataset
-from datalad.api import clone
-from datalad.api import create
-from datalad.api import containers_add
-from datalad.api import containers_run
-from datalad.api import containers_list
-
-from datalad.utils import Path
-from datalad.tests.utils import ok_
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import assert_false
-from datalad.tests.utils import assert_not_in_results
-from datalad.tests.utils import assert_in
-from datalad.tests.utils import assert_result_count
-from datalad.tests.utils import assert_raises
-from datalad.tests.utils import ok_file_has_content
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import with_tree
-from datalad.tests.utils import skip_if_no_network
-from datalad.tests.utils import SkipTest
-from datalad.utils import (
-    chpwd,
-    on_windows,
+from datalad.api import (
+    Dataset,
+    clone,
+    containers_add,
+    containers_list,
+    containers_run,
+    create,
 )
-from datalad.support.network import get_local_file_url
 from datalad.cmd import (
     StdOutCapture,
     WitlessRunner,
 )
+from datalad.support.network import get_local_file_url
+from datalad.tests.utils_pytest import (
+    SkipTest,
+    assert_false,
+    assert_in,
+    assert_not_in_results,
+    assert_raises,
+    assert_result_count,
+    ok_,
+    ok_clean_git,
+    ok_file_has_content,
+    skip_if_no_network,
+    with_tempfile,
+    with_tree,
+)
+from datalad.utils import (
+    Path,
+    chpwd,
+    on_windows,
+)
 
 from datalad_container.tests.utils import add_pyscript_image
 
@@ -38,7 +41,7 @@ testimg_url = 'shub://datalad/datalad-container:testhelper'
 
 @with_tree(tree={"dummy0.img": "doesn't matter 0",
                  "dummy1.img": "doesn't matter 1"})
-def test_run_mispecified(path):
+def test_run_mispecified(path=None):
     ds = Dataset(path).create(force=True)
     ds.save(path=["dummy0.img", "dummy1.img"])
     ok_clean_git(path)
@@ -46,7 +49,7 @@ def test_run_mispecified(path):
     # Abort if no containers exist.
     with assert_raises(ValueError) as cm:
         ds.containers_run("doesn't matter")
-    assert_in("No known containers", str(cm.exception))
+    assert_in("No known containers", str(cm.value))
 
     # Abort if more than one container exists but no container name is
     # specified.
@@ -55,16 +58,16 @@ def test_run_mispecified(path):
 
     with assert_raises(ValueError) as cm:
         ds.containers_run("doesn't matter")
-    assert_in("explicitly specify container", str(cm.exception))
+    assert_in("explicitly specify container", str(cm.value))
 
     # Abort if unknown container is specified.
     with assert_raises(ValueError) as cm:
         ds.containers_run("doesn't matter", container_name="ghost")
-    assert_in("Container selection impossible", str(cm.exception))
+    assert_in("Container selection impossible", str(cm.value))
 
 
 @with_tree(tree={"i.img": "doesn't matter"})
-def test_run_unknown_cmdexec_placeholder(path):
+def test_run_unknown_cmdexec_placeholder(path=None):
     ds = Dataset(path).create(force=True)
     ds.containers_add("i", image="i.img", call_fmt="{youdontknowme}")
     assert_result_count(
@@ -78,7 +81,7 @@ def test_run_unknown_cmdexec_placeholder(path):
 @skip_if_no_network
 @with_tempfile
 @with_tempfile
-def test_container_files(path, super_path):
+def test_container_files(path=None, super_path=None):
     raise SkipTest('SingularityHub is gone for now')
     ds = Dataset(path).create()
     cmd = ['dir'] if on_windows else ['ls']
@@ -154,7 +157,7 @@ def test_container_files(path, super_path):
 
 @with_tempfile
 @with_tree(tree={'some_container.img': "doesn't matter"})
-def test_custom_call_fmt(path, local_file):
+def test_custom_call_fmt(path=None, local_file=None):
     ds = Dataset(path).create()
     subds = ds.create('sub')
 
@@ -192,7 +195,7 @@ def test_custom_call_fmt(path, local_file):
 
 @skip_if_no_network
 @with_tree(tree={"subdir": {"in": "innards"}})
-def test_run_no_explicit_dataset(path):
+def test_run_no_explicit_dataset(path=None):
     raise SkipTest('SingularityHub is gone for now')
     ds = Dataset(path).create(force=True)
     ds.save()
@@ -218,7 +221,7 @@ def test_run_no_explicit_dataset(path):
 
 
 @with_tempfile
-def test_run_subdataset_install(path):
+def test_run_subdataset_install(path=None):
     path = Path(path)
     ds_src = Dataset(path / "src").create()
     # Repository setup
